@@ -1,23 +1,27 @@
-import os
-import requests
-import json
 import decimal
+import json
+import os
 import time
 
+import requests
 
-class ApiUnous:
+from .unous_requests import UnousRequests
+
+
+class ApiUnous(UnousRequests):
     _grant_type = 'password'
     _client_id = 'userIntegration'
     _mindset_user = os.environ.get('MINDSET_USER')
     _mindset_pass = os.environ.get('MINDSET_PASS')
     _mindset_url = os.environ.get('MINDSET_URL')
     _mindset_notify_url = os.environ.get('MINDSET_NOTIFY_URL')
+    show_log = True
 
     @property
     def headers(self):
         return {
             'Content-Type': 'application/json',
-            'Authorization': f'Bearer {self._get_token()}'
+            'Authorization': f'Bearer {self._get_token()}',
         }
 
     def integrar_produtos(self, list):
@@ -47,23 +51,22 @@ class ApiUnous:
             'enterprisePwd': self._mindset_pass,
             'jobName': 'CleanUpJob',
         }
-        response = requests.get(url=self._mindset_notify_url, params=params)
+        response = self.get(url=self._mindset_notify_url, params=params)
         return {
             'ok': response.ok,
             'notificou': response.json().get('StatusReply', '') == 0,
         }
 
+
     def _integrar(self, data, url_endpoint):
-        url = self._mindset_url + url_endpoint
-        offset = 0
-        limit = 10000
+        url, offset, limit = self._mindset_url + url_endpoint, 0, 10000
         for i in range(int(len(data) / limit) + 1):
             conteudo_a_integrar = data[offset:offset + limit]
             conteudo_integrado = len(conteudo_a_integrar)
             if conteudo_integrado > 0:
-                response = requests.post(
+                response = self.post(
                     url=url,
-                    data=json.dumps(conteudo_a_integrar, cls=DecimalEncoder),
+                    json=json.dumps(conteudo_a_integrar, cls=DecimalEncoder),
                     headers=self.headers,
                 )
                 if not response.ok:
@@ -79,16 +82,20 @@ class ApiUnous:
         requests.get(url=url, headers=self.headers)
 
     def _get_token(self):
-        response = requests.get(url=self._mindset_url + '/Auth/token', data={
-            'grant_type': self._grant_type,
-            'username': self._mindset_user,
-            'password': self._mindset_pass,
-            'client_id': self._client_id
-        })
+        response = requests.get(
+            url=self._mindset_url + '/Auth/token',
+            data={
+                'grant_type': self._grant_type,
+                'username': self._mindset_user,
+                'password': self._mindset_pass,
+                'client_id': self._client_id
+            }
+        )
         return json.loads(response.text).get('access_token')
 
 
 class DecimalEncoder(json.JSONEncoder):
+
     def default(self, o):
         if isinstance(o, decimal.Decimal):
             return float(o)
